tombstone_present

Function tombstone_present 

pub fn tombstone_present(root: &Path) -> bool
Whether the tombstone is present.

Re-checked on every append and immediately before every send. This is what makes codewhale config set telemetry false — an external write by another process — observable to a session that is already running.